@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: HAYOBAAN's Pod::Weaver configuration
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 #pod =head1 DESCRIPTION
 #pod
@@ -116,7 +116,7 @@ our $VERSION = '0.002'; # VERSION
 #pod =cut
 
 use Pod::Weaver::Config::Assembler;
-sub _exp { Pod::Weaver::Config::Assembler->expand_package( $_[0] ) }
+sub _exp { return Pod::Weaver::Config::Assembler->expand_package( $_[0] ) }
 
 # Required non-core Pod Weaver modules
 use Pod::Elemental::Transformer::List ();
@@ -190,7 +190,7 @@ Pod::Weaver::PluginBundle::Author::HAYOBAAN - HAYOBAAN's Pod::Weaver configurati
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
